<?php
/*
* Plugin Name: Protect My Courses
* Plugin URI:  https://www.protectmycourses.com/?utm_source=wp-plugins&utm_campaign=plugin-uri&utm_medium=wp-dash
* Description: Easily install the Protect My Courses code on your WordPress Site
* Version: 1.0.0
* Author: Colin Longworth
* Author URI: https://www.protectmycourses.com
* Text Domain: protect-my-courses
* WordPress is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* any later version.
*
* WordPress is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WP_ProtectMyCourses {

	public function __construct() {

		add_action( 'wp_footer', [ $this, 'add_footer_script' ] );

		add_action( 'admin_menu', [ $this, 'protect_my_courses_settings_page' ] );

		add_action( 'admin_init', [ $this, 'protect_my_courses_settings_init' ] );
	}

	public function add_footer_script() {

		if ( is_user_logged_in() ) {

			$options = get_option('protect_my_courses_settings');

            $app_id = $options['app_id'] ?? uniqid('app-id-not-set');

            $secret = $options['secret'] ?? uniqid('secret-not-set');

			$user = wp_get_current_user();

			if ( ! empty( $user->first_name ) ) {
				$name = "$user->first_name $user->last_name";
			} else {
				$name = $user->user_login;
			}

			$name  = apply_filters( 'protect/my/courses/user/name', $name, $user );
			$email = apply_filters( 'protect/my/courses/user/email', $user->user_email, $user );
			$hmac =  apply_filters( 'protect/my/courses/user/hmac', hash_hmac('sha256', $email, $secret), $user );

			?>
            <script>
                /**
                 * Added by ProtectMyCourses.com WordPress Plugin
                 */
                window.dsSettings = {
                    appId: '<?php echo $app_id; ?>',
                    name: '<?php echo $name; ?>',
                    email: '<?php echo $email; ?>',
                    hmac: '<?php echo $hmac;?>'
                };

                !function () {
                    var t = window, e = document, a = function () {
                        var t = e.createElement("script");
                        t.type = "text/javascript", t.async = !0, t.src = "https://www.protectmycourses.com/js/ds.js";
                        var a = e.getElementsByTagName("script")[0];
                        a.parentNode.insertBefore(t, a)
                    };
                    "complete" === document.readyState ? a() : t.attachEvent ? t.attachEvent("onload", a) : t.addEventListener("load", a, !1)
                }();
            </script>
			<?php

		}
	}

	/**
	 * Admin Settings Page
	 */

	public function protect_my_courses_settings_page() {
		add_options_page( 'Protect My Courses', 'Protect My Courses', 'manage_options', 'protect-my-courses', [
			$this,
			'protect_my_courses_options_page'
		] );
	}

	public function protect_my_courses_options_page() {
		?>
        <form action='options.php' method='post'>

            <h2>Settings</h2>

			<?php

			settings_fields( 'protectMyCourses' );

			do_settings_sections( 'protectMyCourses' );

			submit_button();

			?>

        </form>
		<?php
	}

	public function protect_my_courses_settings_init() {

		register_setting( 'protectMyCourses', 'protect_my_courses_settings', [
			$this,
			'protect_my_courses_validation'
		] );

		add_settings_section(
			'protectMyCourses_section',
			__( 'Protect My Courses', 'protect-my-courses' ),
			[ $this, 'protect_my_courses_section_callback' ],
			'protectMyCourses'
		);

		add_settings_field(
			'app_id',
			__( 'App ID', 'protect-my-courses' ),
			[ $this, 'protect_my_courses_render_field' ],
			'protectMyCourses',
			'protectMyCourses_section',
			array( 'app_id', '8gg0a331-f5g2-4219-9263-78ee6e1a7g71' )
		);

		add_settings_field(
			'secret',
			__( 'Secret', 'protect-my-courses' ),
			[ $this, 'protect_my_courses_render_field' ],
			'protectMyCourses',
			'protectMyCourses_section',
			array( 'secret', '8ff0a331-ede4-1218-9211-98ff6e1a7f79' )
		);
	}

	public function protect_my_courses_section_callback() {
		echo __( 'You will need to add your account details exactly as they appear in your ProtectMyCourses.com dashboard.', 'protect-my-courses' );
	}

	public function protect_my_courses_render_field( $args ) {

		$field = $args[0];

		$placeholder = $args[1] ?? '';

		$options = get_option( 'protect_my_courses_settings' );

		$value = $options[ $field ] ?? '';

		?>

        <input type='text' size='50' placeholder='<? echo $placeholder; ?>'
               name='protect_my_courses_settings[<?php echo $field; ?>]' value='<?php echo $value; ?>'>

		<?php

	}

	public function protect_my_courses_validation( $options ) {

		return apply_filters( 'protect/my/courses/options/validation', $options );
	}
}

new WP_ProtectMyCourses();

